Class: Firebug::Configuration
- Inherits:
-
Object
- Object
- Firebug::Configuration
- Defined in:
- lib/firebug/configuration.rb
Overview
A configuration object.
Instance Attribute Summary collapse
-
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
-
#table_name ⇒ String
the name of the sessions table.
-
#truncate_useragent ⇒ Boolean
truncate the user-agent to 120 characters.
Instance Attribute Details
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
9 10 11 |
# File 'lib/firebug/configuration.rb', line 9 def key @key end |
#table_name ⇒ String
the name of the sessions table.
9 10 11 |
# File 'lib/firebug/configuration.rb', line 9 def table_name @table_name end |
#truncate_useragent ⇒ Boolean
truncate the user-agent to 120 characters.
9 10 11 |
# File 'lib/firebug/configuration.rb', line 9 def truncate_useragent @truncate_useragent end |