Class: Firebug::Configuration
- Inherits:
-
Object
- Object
- Firebug::Configuration
- Defined in:
- lib/firebug/configuration.rb
Overview
A configuration object.
Instance Attribute Summary collapse
-
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
-
#match_ip ⇒ Boolean
The current value of match_ip.
-
#match_useragent ⇒ Boolean
The current value of match_useragent.
-
#table_name ⇒ String
the name of the sessions table.
-
#truncate_useragent ⇒ Boolean
The current value of truncate_useragent.
Instance Attribute Details
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
11 12 13 |
# File 'lib/firebug/configuration.rb', line 11 def key @key end |
#match_ip ⇒ Boolean
11 12 13 |
# File 'lib/firebug/configuration.rb', line 11 def match_ip @match_ip end |
#match_useragent ⇒ Boolean
11 12 13 |
# File 'lib/firebug/configuration.rb', line 11 def match_useragent @match_useragent end |
#table_name ⇒ String
the name of the sessions table.
11 12 13 |
# File 'lib/firebug/configuration.rb', line 11 def table_name @table_name end |
#truncate_useragent ⇒ Boolean
11 12 13 |
# File 'lib/firebug/configuration.rb', line 11 def truncate_useragent @truncate_useragent end |