Class: Firebug::Configuration
- Inherits:
-
Object
- Object
- Firebug::Configuration
- Defined in:
- lib/firebug/configuration.rb
Overview
A configuration object.
Instance Attribute Summary collapse
-
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
-
#table_name ⇒ String
the name of the sessions table.
Instance Attribute Details
#key ⇒ String
the encryption key used to encrypt and decrypt cookies.
8 9 10 |
# File 'lib/firebug/configuration.rb', line 8 def key @key end |
#table_name ⇒ String
the name of the sessions table.
8 9 10 |
# File 'lib/firebug/configuration.rb', line 8 def table_name @table_name end |